darkhistory — DarkHistory documentation

# darkhistory

DarkHistory packages.

Modules

`darkhistory.physics` | Physics functions as well as constants.
`darkhistory.utilities` | Non-physics convenience and mathematical functions.

Packages

`darkhistory.electrons` | Electron cooling processes.
`darkhistory.history` | Classes and functions for computing temperature and ionization histories.
`darkhistory.low_energy` | Functions for low-energy deposition and f_c(z).
`darkhistory.spec` | Classes and functions for manipulating spectra.

#### Previous topic

config.load_data

#### Next topic

darkhistory.physics

### This Page

Show Source